OiRA

Help

1. Préparation
2. Impliquer
3. Identification + Estimation
4. Plan d'action
   1. 1.1.1 Slips, trips and falls are not prevented.
   2. 1.1.2 Collisions, bumps, and jamming are not prevented.
   3. 1.1.4 Exposure to noise is neither prevented nor controlled.
   4. 1.1.6 Exposure to biological substances is neither prevented nor controlled
   5. Ω.1 The entrance floor is often wet
   6. Title of the first custom risk
   7. This is another custom risk added by the user
   - Attention
5. Rapport
6. Avancement 9%

# Commercial guarding, Leicester

Vous avez identifié et estimé les risques dans votre entreprise. Pendant l’élaboration du plan d'action, vous pourrez ajuster la priorité de chaque situation à risque et définir comment y remédier. Trois niveaux de priorité du risque sont proposés : "faible", "moyen", "élevé". Par exemple, le niveau de priorité du risque élevé peut être associé à une atteinte grave à la santé ou à une exposition fréquente des salariés.

Il est recommandé de s'attaquer à la source des problèmes afin de supprimer le risque. Vous écrirez alors quelles tâches doivent être effectuées afin d’éliminer le risque, ainsi que les connaissances et l'expérience nécessaires pour que ces tâches soient effectuées. Les questions à se poser :

1. Le risque est-il évitable ? Peut-il être totalement supprimé ? Si oui, comment ?
   - La tâche dangereuse peut-elle être évitée ?
   - Le produit dangereux peut-il être remplacé ?
2. Si certains risques ne sont pas évitables, comment peuvent-ils être réduits à un niveau tel que la santé et la sécurité des salariés exposés ne soient pas compromises ?

Vous pouvez définir vos propres mesures de prévention ou utiliser, (et éventuellement adapter), celles qui vous sont proposées dans l’outil (menu déroulant [pré-remplir]).

Pour intégrer une mesure, vous devez :

- Soit la choisir dans le menu « pré-remplir » (vous pourrez ensuite l’adapter)
- Soit la renseigner vous-même en :
  - précisant les actions à mettre en place pour la rendre effective (2ème champ)
  - indiquant les compétences spécifiques nécessaires pour l’appliquer ou préciser quelle(s) fonction(s) de l'entreprise est (sont) à mobiliser (3ème champ).

Vous pouvez intégrer plusieurs mesures pour un même risque.

Créer un plan d'action

Scroll to top
Back

## action-plan-landing.html

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More